<?php

/**
 * THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 *
 * @package clearFusionCMS\module\dashrssfeed
 * @copyright Copyright (c) 2013 - 2017 clearFusionCMS. All rights reserved.
 * @link http://clearfusioncms.com
 */

/**
 * dashrssfeedInstall Class
 *
 * Class for managing the dashboard RSS feed module installation.
 *
 * @package clearFusionCMS\module\dashrssfeed
 */
class dashrssfeedInstall implements cfInstallInterface {
	/**
	 * The last error message.
	 *
	 * @var string
	 */
	protected $lastError = '';

	/**
	 * Return the last error.
	 *
	 * @return string The last error string.
	 */
	function getLastError() {
		return $this->lastError;
	}

	/**
	 * Install the module.
	 *
	 * @param flDb The database object to use.
	 * @return bool true if installed; else false.
	 */
	function install($db) {
		// Add dashboard group
		$dmgr = new cfDashboardMgr($db);
		$dmgr->addGroup('cfdashrssfeed', 1100, __noop('RSS Feed'), 'dashrssfeedBackend');

		// Capture draw events
		$em = clearFusionCMS::getEventManager();
		$em->addListener('system.managerDrawBlock', 'dashrssfeedEvents', 'onManagerBlock');

		$cron = new flCron($db);
		$cron->addJob('0 */6 * * * *', 'dashrssfeedEvents', 'onCron');

		// Install config
		$cfg = new flConfigDb('cfdashrssfeed', $db);
		$cfg->title = 'RSS';
		$cfg->uri = '';

		// Permissions
		$ac = new flAcMgr($db);
		$ac->createPermissionGroup('cfdashrssfeed', __noop('Dash RSS Feed'), 'dashrssfeedBackend'); // 6000
		$ac->createPermission('cfdashrssfeed.settings', __noop('Can edit dash RSS feed settings.'), 6000, 'dashrssfeedBackend');

		return true;
	}

	/**
	 * Uninstall the module.
	 *
	 * @param flDb The database object to use.
	 * @return bool true if uninstalled; else false.
	 */
	function uninstall($db) {
		// Remove listeners
		$em = clearFusionCMS::getEventManager();
		$em->removeListener('system.managerDrawBlock', 'dashrssfeedEvents', 'onManagerBlock');

		$cron = new flCron($db);
		$cron->deleteJob('dashrssfeedEvents', 'onCron');

		// Remove from dashboard
		$dmgr = new cfDashboardMgr($db);
		$dmgr->delGroup('cfdashrssfeed');

		// Drop config
		$cfg = new flConfigDb('cfdashrssfeed', $db);
		$cfg->deleteNamespace();

		// Remove permissions
		$ac = new flAcMgr($db);
		$ac->deletePermissionGroup('cfdashrssfeed');

		// Drop variables
		$var = new flVariables('cfdashrssfeed', $db);
		$var->deleteNamespace();

		return true;
	}

	/**
	 * Upgrade the module.
	 *
	 * @param flDb The database object to use.
	 * @param string $installedVer The installed version.
	 * @return bool true if upgraded; else false.
	 */
	function upgrade($db, $installedVer) {
		if(version_compare($installedVer, '1.2.0') < 0) {
			$em = clearFusionCMS::getEventManager();
			$em->removeListener('system.cron6h', 'dashrssfeedEvents', 'onCron');
			$cron = new flCron($db);
			$cron->addJob('0 */6 * * * *', 'dashrssfeedEvents', 'onCron');
		}
		return true;
	}

	/**
	 * Create a new site.
	 *
	 * @param flDb $db The database object.
	 * @param string $site The short name of the site.
	 * @return bool true if the site was created; else false.
	 */
	function createSite($db, $site) {
		return true;
	}

	/**
	 * Delete a site.
	 *
	 * @param flDb $db The database object.
	 * @param string $site The name of the site to delete.
	 * @return bool true if the site was deleted; else false.
	 */
	function deleteSite($db, $site) {
		return true;
	}
}
