<?php

/**
 * THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 *
 * @package clearFusionCMS\module\dashrssfeed
 * @copyright Copyright (c) 2013 clearFusionCMS. All rights reserved.
 * @link http://clearfusioncms.com
 */

/**
 * dashrssfeedSettings Class
 *
 * Class to implement settings for the dashboard twitter feed.
 *
 * @package clearFusionCMS\module\dashrssfeed
 */
class dashrssfeedSettings implements cfModuleSettingsInterface {

	/**
	 * Get a list of settings groups.
	 *
	 * @return array Array of setting groups, name => func name
	 */
	function getSettingsGroups() {
		if(!clearFusionCMS::getUser()->hasPermission('cfdashrssfeed.settings'))
			return array();

		return array(
			__('Settings', 'dashrssfeedBackend') => 'gen'
		);
	}

	/**
	 * Implement general settings.
	 *
	 * @param flForm $form The form object to use.
	 * @param flDb $db The database object.
	 * @return bool true if the settings were updated, false if failed to update or null if no change.
	 */
	function genSetting($form, $db) {
		if(!clearFusionCMS::getUser()->hasPermission('cfdashrssfeed.settings'))
			return null;

		$cfg = new flConfigDb('cfdashrssfeed', clearFusionCMS::getDb());

		$title = new flFormElementText($form, 'title', $cfg->title);
		$title->setLabel(__('Block Title', 'dashrssfeedBackend'))
			->setRequired()
			->addValidator(new flFormValidatorRequired())
			->addValidator(new flFormValidatorMaxLength(200));

		$uri = new flFormElementUri($form, 'uri', $cfg->uri);
		$uri->setLabel(__('Feed Address', 'dashrssfeedBackend'))
			->addValidator(new flFormValidatorMaxLength(255));

		$submit = new flFormElementSubmit($form, 'update');
		$submit->setCaption(__('Update Settings', 'dashrssfeedBackend'))->setCSS('primary');

		$form->focusElement($title);

		if($form->isSubmitted() && $form->isValid()) {
			$cfg->title = $title->getValue();
			$cfg->uri = $uri->getValue();

			$rss = new flRssClient(null);
			if($channel = $rss->fetch($cfg->uri, 3)) {
				$var = new flVariables('cfdashrssfeed', clearFusionCMS::getDb());
				$var->feed = serialize($channel);
			}

			return true;
		}

		return null;
	}
}
